==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_functions/mp0220_001/MP0220_AddIssueReturnTransaction_001.java <==

package net.datastream.schemas.mp_functions.mp0220_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.issuereturntransaction_001.IssueReturnTransaction;
import net.datastream.schemas.mp_fields.BaseSchemaRequestElement;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;extension base="{http://schemas.datastream.net/MP_fields}BaseSchemaRequestElement">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/IssueReturnTransaction_001}IssueReturnTransaction"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Add" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="IssueReturnTransaction" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="isCoreLabelPrinted" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="confirm_printcorereturnlabel" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "issueReturnTransaction"
})
@XmlRootElement(name = "MP0220_AddIssueReturnTransaction_001")
public class MP0220_AddIssueReturnTransaction_001
    extends BaseSchemaRequestElement
{

    @XmlElement(name = "IssueReturnTransaction", namespace = "http://schemas.datastream.net/MP_entities/IssueReturnTransaction_001", required = true)
    protected IssueReturnTransaction issueReturnTransaction;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "isCoreLabelPrinted")
    protected String isCoreLabelPrinted;
    @XmlAttribute(name = "confirm_printcorereturnlabel")
    protected String confirm_Printcorereturnlabel;

    /**
     * Obtient la valeur de la propriété issueReturnTransaction.
     * 
     * @return
     *     possible object is
     *     {@link IssueReturnTransaction }
     *     
     */
    public IssueReturnTransaction getIssueReturnTransaction() {
        return issueReturnTransaction;
    }

    /**
     * Définit la valeur de la propriété issueReturnTransaction.
     * 
     * @param value
     *     allowed object is
     *     {@link IssueReturnTransaction }
     *     
     */
    public void setIssueReturnTransaction(IssueReturnTransaction value) {
        this.issueReturnTransaction = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.ADD;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.ISSUE_RETURN_TRANSACTION;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Obtient la valeur de la propriété isCoreLabelPrinted.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIsCoreLabelPrinted() {
        if (isCoreLabelPrinted == null) {
            return "false";
        } else {
            return isCoreLabelPrinted;
        }
    }

    /**
     * Définit la valeur de la propriété isCoreLabelPrinted.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIsCoreLabelPrinted(String value) {
        this.isCoreLabelPrinted = value;
    }

    /**
     * Obtient la valeur de la propriété confirm_Printcorereturnlabel.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Printcorereturnlabel() {
        if (confirm_Printcorereturnlabel == null) {
            return "not_needed";
        } else {
            return confirm_Printcorereturnlabel;
        }
    }

    /**
     * Définit la valeur de la propriété confirm_Printcorereturnlabel.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Printcorereturnlabel(String value) {
        this.confirm_Printcorereturnlabel = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_functions/mp0220_001/MP0220_AddIssueReturnTransaction_001.java <==

package net.datastream.schemas.mp_functions.mp0220_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.issuereturntransaction_001.IssueReturnTransaction;
import net.datastream.schemas.mp_fields.BaseSchemaRequestElement;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <extension base="{http://schemas.datastream.net/MP_fields}BaseSchemaRequestElement">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_entities/IssueReturnTransaction_001}IssueReturnTransaction"/>
 *       </sequence>
 *       <attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Add" />
 *       <attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="IssueReturnTransaction" />
 *       <attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       <attribute name="isCoreLabelPrinted" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       <attribute name="confirm_printcorereturnlabel" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "issueReturnTransaction"
})
@XmlRootElement(name = "MP0220_AddIssueReturnTransaction_001")
public class MP0220_AddIssueReturnTransaction_001
    extends BaseSchemaRequestElement
{

    @XmlElement(name = "IssueReturnTransaction", namespace = "http://schemas.datastream.net/MP_entities/IssueReturnTransaction_001", required = true)
    protected IssueReturnTransaction issueReturnTransaction;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "isCoreLabelPrinted")
    protected String isCoreLabelPrinted;
    @XmlAttribute(name = "confirm_printcorereturnlabel")
    protected String confirm_Printcorereturnlabel;

    /**
     * Gets the value of the issueReturnTransaction property.
     * 
     * @return
     *     possible object is
     *     {@link IssueReturnTransaction }
     *     
     */
    public IssueReturnTransaction getIssueReturnTransaction() {
        return issueReturnTransaction;
    }

    /**
     * Sets the value of the issueReturnTransaction property.
     * 
     * @param value
     *     allowed object is
     *     {@link IssueReturnTransaction }
     *     
     */
    public void setIssueReturnTransaction(IssueReturnTransaction value) {
        this.issueReturnTransaction = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.ADD;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.ISSUE_RETURN_TRANSACTION;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the isCoreLabelPrinted property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIsCoreLabelPrinted() {
        if (isCoreLabelPrinted == null) {
            return "false";
        } else {
            return isCoreLabelPrinted;
        }
    }

    /**
     * Sets the value of the isCoreLabelPrinted property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIsCoreLabelPrinted(String value) {
        this.isCoreLabelPrinted = value;
    }

    /**
     * Gets the value of the confirm_Printcorereturnlabel property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Printcorereturnlabel() {
        if (confirm_Printcorereturnlabel == null) {
            return "not_needed";
        } else {
            return confirm_Printcorereturnlabel;
        }
    }

    /**
     * Sets the value of the confirm_Printcorereturnlabel property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Printcorereturnlabel(String value) {
        this.confirm_Printcorereturnlabel = value;
    }

}
